#!/usr/bin/env python

"Test of elements and attribute interfaces."

import libxml2dom

d = libxml2dom.parseString("<ddd:doc xmlns:ddd='http://ddd'/>")
e = d.xpath("*")[0]
assert e.parentNode == d
assert e.namespaceURI == "http://ddd"
assert e.nodeName == e.tagName == "ddd:doc"
assert e.localName == "doc"
print d.toString()

e.setAttributeNS("http://xxx", "xxx:x", "y")
assert e.getAttributeNS("http://xxx", "x") == "y"
l = e.xpath("@*")
assert len(l) == 1
a = l[0]
assert a.parentNode == e
assert a.namespaceURI == "http://xxx"
assert a.nodeName == "xxx:x"
assert a.localName == "x"
assert a.nodeValue == a.value == "y"
print d.toString()

a2 = d.createAttributeNS("http://aaa", "aaa:a")
a2.nodeValue = "b"
assert a2.namespaceURI == "http://aaa"
assert a2.nodeName == "aaa:a"
assert a2.localName == "a"
assert a2.nodeValue == a2.value == "b"
print d.toString()

e.setAttributeNodeNS(a2)
l2 = e.xpath("@*")
assert len(l2) == 2
print d.toString()

e.setAttributeNS("http://ccc", "ccc:c", "d")
assert e.getAttributeNS("http://ccc", "c") == "d"
l3 = e.xpath("@*")
assert len(l3) == 3
e.setAttribute("p", "q")
assert e.getAttribute("p") == "q"
l4 = e.xpath("@*")
assert len(l4) == 4
al = e.attributes
assert len(al.items()) == 4
a3 = al.getNamedItemNS("http://ccc", "c")
assert a3.namespaceURI == "http://ccc"
assert a3.nodeName == "ccc:c"
assert a3.localName == "c"
assert a3.nodeValue == "d"
print d.toString()

a4 = e.createAttribute("m")
a4.nodeValue = "n"
assert a4.namespaceURI == None
assert a4.nodeName == "m"
assert a4.localName == "m"
assert a4.nodeValue == a4.value == "n"
print d.toString()

a4_old = al.setNamedItem(a4)
assert a4_old == None
assert len(al.items()) == 5
assert e.getAttribute("m") == "n"
al.removeNamedItem("m")
assert not e.hasAttribute("m")
assert len(al.items()) == 4
e.removeAttributeNS("http://ccc", "c")
assert not e.hasAttributeNS("http://ccc", "c")
l5 = e.xpath("@*")
assert len(l5) == 3
e.removeAttribute("p")
assert not e.hasAttribute("p")
l6 = e.xpath("@*")
assert len(l6) == 2
print d.toString()

# vim: tabstop=4 expandtab shiftwidth=4
